@@ -18,12 +18,14 @@
 #' with(mtcars, plot(mpg, wt))
 #'
 preview_docs <- function(path = ".") {
-  .assert_dependency("servr", install = TRUE)
+    .assert_dependency("servr", install = TRUE)
 
-  tool <- .doc_type(path)
-  if (.folder_is_empty(fs::path_join(c(path, "docs")))) {
-    cli::cli_abort("You must render the docs before previewing them. Use {.code altdoc::render_docs()}.")
-  }
+    tool <- .doc_type(path)
+    if (.folder_is_empty(fs::path_join(c(path, "docs")))) {
+        cli::cli_abort(
+            "You must render the docs before previewing them. Use {.code altdoc::render_docs()}."
+        )
+    }
 
-  servr::httw(fs::path_join(c(path, "docs")))
+    servr::httw(fs::path_join(c(path, "docs")))
 }
