@@ -8,7 +8,8 @@
     # Fix vignette relative links
     vignettes <- list.files(
         fs::path_join(c(.doc_path(path), "vignettes")),
-        pattern = "\\.md")
+        pattern = "\\.md"
+    )
     vignettes <- gsub("\\.md$", "", vignettes)
     for (v in vignettes) {
         fn <- fs::path_join(c(.doc_path(path), "vignettes", paste0(v, ".md")))
@@ -17,14 +18,16 @@
             paste0("![](", v),
             paste0("![](vignettes/", v),
             txt,
-            fixed = TRUE)
+            fixed = TRUE
+        )
         writeLines(txt, fn)
     }
 
     # Fix man relative links
     man <- list.files(
         fs::path_join(c(.doc_path(path), "man")),
-        pattern = "\\.md")
+        pattern = "\\.md"
+    )
     man <- gsub("\\.md$", "", man)
     for (v in man) {
         fn <- fs::path_join(c(.doc_path(path), "man", paste0(v, ".md")))
@@ -34,12 +37,12 @@
             paste0("![](", v),
             paste0("![](man/", v),
             txt,
-            fixed = TRUE)
+            fixed = TRUE
+        )
         writeLines(txt, fn)
     }
 }
 
-
 .sidebar_vignettes_docute <- function(sidebar, path) {
     dn <- fs::path_join(c(.doc_path(path), "vignettes"))
     fn_vignettes <- list.files(dn, pattern = "\\.md$", full.names = TRUE)
@@ -58,7 +61,7 @@
 
     if (length(fn_vignettes) > 0) {
         tmp <- sprintf("{title: '%s', link: '%s'}", titles, fn_vignettes)
-        tmp <- paste(tmp, collapse = ", ")
+        tmp <- toString(tmp)
         sidebar <- paste(sidebar, collapse = "\n")
         if (isTRUE(grepl("\\$ALTDOC_VIGNETTE_BLOCK", sidebar))) {
             sidebar <- gsub("\\$ALTDOC_VIGNETTE_BLOCK", "%s", sidebar)
@@ -71,17 +74,19 @@
     return(sidebar)
 }
 
-
 .sidebar_man_docute <- function(sidebar, path) {
     fn_man <- fs::path_join(c(.doc_path(path), "reference.md"))
     dn_man <- fs::path_join(c(.doc_path(path), "man"))
     # multi page
     if (fs::dir_exists(dn_man) && length(fs::dir_ls(dn_man)) > 0) {
         fn_man <- list.files(dn_man, pattern = "\\.md$", full.names = TRUE)
-        fn_man <- sapply(fn_man, function(x) fs::path_join(c("/man", basename(x))))
+        fn_man <- sapply(
+            fn_man,
+            function(x) fs::path_join(c("/man", basename(x)))
+        )
         titles <- fs::path_ext_remove(basename(fn_man))
         tmp <- sprintf("{title: '%s', link: '%s'}", titles, fn_man)
-        tmp <- paste(tmp, collapse = ", ")
+        tmp <- toString(tmp)
         sidebar <- paste(sidebar, collapse = "\n")
         if (isTRUE(grepl("\\$ALTDOC_MAN_BLOCK", sidebar))) {
             sidebar <- gsub("\\$ALTDOC_MAN_BLOCK", "%s", sidebar)
